@@ -15,12 +15,7 @@ filterSpecifics<-function(y, box.cox, trend, damping, seasonal.periods, use.arma
 		}
 	}
 	if(use.arma.errors) {
-		##Turn off warnings
-		old.warning.level <- options()$warn
-		options(warn=-1)
-		arma <- auto.arima(as.numeric(first.model$errors), d=0, ...)
-		###Re-enable warnings
-		options(warn=old.warning.level)
+		suppressWarnings(arma <- auto.arima(as.numeric(first.model$errors), d=0, ...))
 		p <- arma$arma[1]
 		q <- arma$arma[2]
 		if((p != 0) | (q != 0)) { #Did auto.arima() find any AR() or MA() coefficients?
@@ -70,12 +65,7 @@ parFilterSpecifics<-function(control.number, control.array, y, seasonal.periods,
 		}
 	}
 	if(use.arma.errors) {
-		##Turn off warnings
-		old.warning.level <- options()$warn
-		options(warn=-1)
-		arma <- auto.arima(as.numeric(first.model$errors), d=0, ...)
-		###Re-enable warnings
-		options(warn=old.warning.level)
+		suppressWarnings(arma <- auto.arima(as.numeric(first.model$errors), d=0, ...))
 		p <- arma$arma[1]
 		q <- arma$arma[2]
 		if((p != 0) | (q != 0)) { #Did auto.arima() find any AR() or MA() coefficients?
